==> nextcloud-29.0.12.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Nube Federada no válida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirá una invitación. Compruebe sus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un recurso compartido federado, parece ser que el servidor con el que se intenta federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar recursos compartidos federados de grupos desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No se pudo compartir %1$s porque este ítem ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share to the same account" : "No está permitido crear un recurso compartido federado a la misma cuenta",
    "Federated shares require read permissions" : "Los recursos compartidos federados necesitan permiso de lectura",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Federated Cloud Sharing" : "Compartido en Nube Federada",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajustar la forma en que los usuarios pueden compartir entre servidores. Esto incluye a los recursos compartidos entre usuarios en este servidor tanto como a aquellos que usan compartición federada",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir a los usuarios en este servidor enviar recursos compartidos a otros servidores (esta opción también permite el acceso público vía WebDAV a los recursos compartidos públicos)",
    "Allow people on this server to receive shares from other servers" : "Permitir a los usuarios de este servidor recibir recursos compartidos de otros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitir a los usuarios en este servidor enviar recursos compartidos a grupos en otros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitir a los usuarios de este servidor recibir recursos compartidos de grupo de otros servidores",
    "Search global and public address book for people" : "Buscar usuarios tanto en la libreta global de direcciones como en la pública",
    "Allow people to publish their data to a global and public address book" : "Permitir a los usuarios publicar sus datos tanto a una libreta de direcciones global como a una pública",
    "Trusted federation" : "Federación de confianza",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceptar automáticamente recursos compartidos de cuentas y grupos de federaciones de confianza por defecto",
    "Unable to update federated files sharing config" : "No fue posible actualizar la configuración de los recursos compartidos federados de archivos",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puede compartir con cualquier persona que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)!. Solo coloque el ID de Nube Federada de esta(s) persona(s) en el diálogo de compartir. Se verán así: persona@nube.ejemplo.com",
    "Your Federated Cloud ID" : "Tu ID de Nube Federada",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "formerly Twitter" : "anteriormente Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi ID de Nube Federada #Nextcloud, ve {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Clipboard not available. Please copy the cloud ID manually." : "Portapapeles no disponible. Por favor, copia el ID de nube manualmente.",
    "Copied!" : "¡Copiado!",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Remote share" : "Recurso compartido remoto",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share password" : "Contraseña del compartido remoto",
    "Incoming share could not be processed" : "Elemento compartido entrante no pudo ser procesado",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "El portapapeles no está disponible"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de Nube Federada no válida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirá una invitación. Compruebe sus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un recurso compartido federado, parece ser que el servidor con el que se intenta federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar recursos compartidos federados de grupos desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No se pudo compartir %1$s porque este ítem ya está compartido con el usuario %2$s",
    "Not allowed to create a federated share to the same account" : "No está permitido crear un recurso compartido federado a la misma cuenta",
    "Federated shares require read permissions" : "Los recursos compartidos federados necesitan permiso de lectura",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Federated Cloud Sharing" : "Compartido en Nube Federada",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Confirm data upload to lookup server" : "Confirmar la carga de datos para el servidor de búsqueda",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Cuando está habilitado, todas las propiedades de las cuentas (p.ej. direcciones de correo electrónico) que se posean el ámbito de visibilidad establecido a \"publicada\" serán automáticamente sincronizadas y transmitidas a un sistema externo y se harán disponible en una libreta de direcciones pública global.",
    "Disable upload" : "Deshabilitar subidas",
    "Enable data upload" : "Habilitar la subida de datos",
    "Confirm querying lookup server" : "Confirmar la consulta al servidor de búsqueda",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Cuando está habilitado, cualquier entrada en la búsqueda cuando se crean recursos compartidos será enviada a un sistema externo que provee una libreta de direcciones pública global.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Esto se utiliza para obtener el ID de nube federada para hacer más sencilla la compartición federada. ",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Además, las direcciones de correo electrónico de los usuarios podrían ser enviadas a este sistema de manera de verificarlas.",
    "Disable querying" : "Deshabilitar consultas",
    "Enable querying" : "Habilitar consultas",
    "Unable to update federated files sharing config" : "No fue posible actualizar la configuración de los recursos compartidos federados de archivos",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajustar la forma en que los usuarios pueden compartir entre servidores. Esto incluye a los recursos compartidos entre usuarios en este servidor tanto como a aquellos que usan compartición federada",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitir a los usuarios en este servidor enviar recursos compartidos a otros servidores (esta opción también permite el acceso público vía WebDAV a los recursos compartidos públicos)",
    "Allow people on this server to receive shares from other servers" : "Permitir a los usuarios de este servidor recibir recursos compartidos de otros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitir a los usuarios en este servidor enviar recursos compartidos a grupos en otros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitir a los usuarios de este servidor recibir recursos compartidos de grupo de otros servidores",
    "The lookup server is only available for global scale." : "El servidor de búsqueda solo está disponible a escala global.",
    "Search global and public address book for people" : "Buscar usuarios tanto en la libreta global de direcciones como en la pública",
    "Allow people to publish their data to a global and public address book" : "Permitir a los usuarios publicar sus datos tanto a una libreta de direcciones global como a una pública",
    "Trusted federation" : "Federación de confianza",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceptar automáticamente recursos compartidos de cuentas y grupos de federaciones de confianza por defecto",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparte conmigo a través de mi ID de Nube Federada #Nextcloud, ve {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Cloud ID copied to the clipboard" : "ID de nube copiado al portapapeles",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Clipboard not available. Please copy the cloud ID manually." : "Portapapeles no disponible. Por favor, copia el ID de nube manualmente.",
    "Copied!" : "¡Copiado!",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puede compartir con cualquier persona que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)!. Solo coloque el ID de Nube Federada de esta(s) persona(s) en el diálogo de compartir. Se verán así: persona@nube.ejemplo.com",
    "Your Federated Cloud ID" : "Tu ID de Nube Federada",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "formerly Twitter" : "anteriormente Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Remote share" : "Recurso compartido remoto",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share password" : "Contraseña del compartido remoto",
    "Incoming share could not be processed" : "Elemento compartido entrante no pudo ser procesado"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
